==> php54-owncloud-8.0.4.tgz: share/owncloud/apps/activity/l10n/sk_SK.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivita",
    "Your settings have been updated." : "Vaše nastavenia boli aktualizované.",
    "A file or folder has been <strong>shared</strong>" : "Súbor alebo priečinok bol <strong>zdieľaný</strong>",
    "A new file or folder has been <strong>created</strong>" : "Nový súbor alebo priečinok bol <strong>vytvorený</strong>",
    "A file or folder has been <strong>changed</strong>" : "Súbor alebo priečinok bol <strong>zmenený</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Súbor alebo priečinok bol <strong>odstránený</strong>",
    "A file or folder has been <strong>restored</strong>" : "Súbor alebo priečinok bol <strong>obnovený</strong>",
    "You created %1$s" : "Bol vytvorený %1$s",
    "%2$s created %1$s" : "%2$s vytvoril %1$s",
    "%1$s was created in a public folder" : "%1$s vytvorený vo verejnom priečinku",
    "You changed %1$s" : "Bol zmenený %1$s",
    "%2$s changed %1$s" : "%2$s zmenil %1$s",
    "You deleted %1$s" : "Bol zmazaný %1$s",
    "%2$s deleted %1$s" : "%2$s zmazal %1$s",
    "You restored %1$s" : "Bol obnovený %1$s",
    "%2$s restored %1$s" : "%2$s obnovil %1$s",
    "You shared %1$s with %2$s" : "Bol zdieľaný %1$s s %2$s",
    "You shared %1$s with group %2$s" : "Bol zdieľaný %1$s so skupinou %2$s",
    "%2$s shared %1$s with you" : "%2$s vám zdieľal %1$s",
    "You shared %1$s via link" : "Zdieľate %1$s prostredníctvom odkazu",
    "Activity notification" : "Upozornenia na aktivity",
    "All Activities" : "Všetky aktivity",
    "Activities by you" : "Vaše aktivity",
    "Activities by others" : "Aktivity ostatných",
    "Shares" : "Zdieľanie",
    "Files" : "Súbory",
    "\"remote user\"" : "\"remote user\"",
    "in %s" : "v %s",
    "%s and %s" : "%s a %s",
    ", " : ", ",
    "%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>::%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>" : ["%s a <strong class=\"tooltip\" title=\"%s\">%n ďalších</strong>","%s a <strong class=\"tooltip\" title=\"%s\">%n ďalších</strong>","%s a <strong class=\"tooltip\" title=\"%s\">%n ďalších</strong>"],
    "%s and %n more::%s and %n more" : ["%s a %n ďalších","%s a %n ďalších","%s a %n ďalších"],
    "Hello %s," : "Ahoj %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Tento email dostávate preto, lebo v uplynulej hodine došlo v %s k týmto udalostiam",
    "You are receiving this email because in the last day the following things happened at %s" : "Tento email dostávate preto, lebo za posledný deň došlo v %s k týmto udalostiam",
    "You are receiving this email because in the last week the following things happened at %s" : "Tento email dostávate preto, lebo za posledný týždeň došlo v %s k týmto udalostiam",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "You will see a list of events here when you start to use your %s." : "Tu uvidíte zoznam udalostí hneď ako začnete používať svoj %s.",
    "No more events to load" : "Žiadne ďalšie udalosti na načítanie",
    "Enable RSS feed" : "Povoliť RSS kanál",
    "Notifications" : "Oznámenia",
    "Mail" : "Pošta",
    "Stream" : "Stream",
    "List your own actions in the stream" : "Zobrazovať vlastné činnosti v zozname",
    "Notify about your own actions via email" : "Poslať oznámenie o vlastnej činnosti emailom",
    "You need to set up your email address before you can receive notification emails." : "Ak chcete dostávať oznámenia emailom, musíte najskôr vyplniť vašu emailovú adresu.",
    "Send emails:" : "Odoslať emaily:",
    "Hourly" : "Každú hodinu",
    "Daily" : "Denne",
    "Weekly" : "Týždenne",
    "Activity feed" : "Prehľad aktivít",
    "Personal activity feed for %s" : "Prehľad aktivít pre používateľa %s"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/activity/l10n/sk_SK.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivita",
    "Personal activity feed for %s" : "Prehľad aktivít pre používateľa %s",
    "Your feed URL is invalid" : "Váš kanál URL je neplatný",
    "Your settings have been updated." : "Vaše nastavenia boli aktualizované.",
    "This stream will show events like additions, changes & shares" : "Tento dátový prúd bude zobrazovať udalosti ako pridanie, zmeny a zdieľanie",
    "There are no events for this filter" : "Pre tieto kritériá nie sú žiadne udalosti",
    "Activity notification" : "Upozornenia na aktivity",
    "All Activities" : "Všetky aktivity",
    "Activities by you" : "Vaše aktivity",
    "Activities by others" : "Aktivity ostatných",
    "\"remote user\"" : "\"vzdialený používateľ\"",
    "in %s" : "v %s",
    "%s and %s" : "%s a %s",
    ", " : ", ",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s a <strong class=\"tooltip\" title=\"%s\">%n ďalších</strong>","%s a <strong class=\"tooltip\" title=\"%s\">%n ďalších</strong>","%s a <strong class=\"tooltip\" title=\"%s\">%n ďalších</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s a %n ďalších","%s a %n ďalších","%s a %n ďalších"],
    "Hello %s," : "Ahoj %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Tento email dostávate preto, lebo v uplynulej hodine došlo v %s k týmto udalostiam",
    "You are receiving this email because in the last day the following things happened at %s" : "Tento email dostávate preto, lebo za posledný deň došlo v %s k týmto udalostiam",
    "You are receiving this email because in the last week the following things happened at %s" : "Tento email dostávate preto, lebo za posledný týždeň došlo v %s k týmto udalostiam",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* a %n ďalší ","* a %n ďalšie ","* a %n ďalších "],
    "Notifications" : "Oznámenia",
    "Mail" : "Pošta",
    "Stream" : "Stream",
    "List your own actions in the stream" : "Zobrazovať vlastné činnosti v zozname",
    "Notify about your own actions via email" : "Poslať oznámenie o vlastnej činnosti emailom",
    "You need to set up your email address before you can receive notification emails." : "Ak chcete dostávať oznámenia emailom, musíte najskôr vyplniť vašu emailovú adresu.",
    "Send emails:" : "Odoslať emaily:",
    "Hourly" : "Každú hodinu",
    "Daily" : "Denne",
    "Weekly" : "Týždenne",
    "Activity feed" : "Prehľad aktivít",
    "Enable RSS feed" : "Povoliť RSS kanál",
    "No activity yet" : "Zatiaľ žiadne aktivity.",
    "No more events to load" : "Žiadne ďalšie udalosti na načítanie",
    "Files" : "Súbory"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
